Daemon

Struct Daemon 

pub struct Daemon { /* private fields */ }
A running daemon.

The daemon process is killed, when the Daemon struct is dropped.

Implementations

Source

impl Daemon

pub fn stop(&mut self) -> Result<(), DaemonError>

Explicitly stop a daemon.

Calling this function is only useful if you want to handle errors. It can only be called once.

pub fn stdout(&self) -> Result<Vec<u8>, DaemonError>

Return what the daemon has written to its stderr so far.

pub fn stderr(&self) -> Result<Vec<u8>, DaemonError>

Return what the daemon has written to its stderr so far.