Step

Enum Step 

pub enum Step {
    Start(String),
    Stop(String),
    Create(Create),
    Rename(FileCount),
    Delete(FileCount),
    Backup(usize),
    Restore(usize),
    ManifestLive(usize),
    ManifestRestored(usize),
    CompareManifests(usize, usize),
}
A step specification in the execution of a benchmark.

Variants



Start(String)

Start a benchmark.

Tuple Fields

0: String

Unique name of the benchmark.



Stop(String)

Finish a benchmark with a given name.

Tuple Fields

0: String

Unique name of the benchmark.



Create(Create)

Create test data files.



Rename(FileCount)

Rename test data files.



Delete(FileCount)

Delete test data files.



Backup(usize)

Make the nth backup in the benchmark.

Tuple Fields

0: usize

n



Restore(usize)

Restore the nth backup in the benchmark.

Tuple Fields

0: usize

n



ManifestLive(usize)

Create and remember a manifest of current live data. Call it id.

Tuple Fields

0: usize

id



ManifestRestored(usize)

Create and remember a manifest of latest restored data. Call it id.

Tuple Fields

0: usize

id



CompareManifests(usize, usize)

Compare two manifests for equality.

Tuple Fields

0: usize

First

1: usize

Second.