pub enum Step {
Start(String),
Stop(String),
Create(Create),
Rename(FileCount),
Delete(FileCount),
Backup(usize),
Restore(usize),
ManifestLive(usize),
ManifestRestored(usize),
CompareManifests(usize, usize),
}Expand description
A step specification in the execution of a benchmark.
Variants
Start(String)
Start a benchmark.
Stop(String)
Finish a benchmark with a given name.
Create(Create)
Create test data files.
Rename(FileCount)
Rename test data files.
Delete(FileCount)
Delete test data files.
Backup(usize)
Make the nth backup in the benchmark.
Restore(usize)
Restore the nth backup in the benchmark.
ManifestLive(usize)
Create and remember a manifest of current live data. Call it id.
ManifestRestored(usize)
Create and remember a manifest of latest restored data. Call it id.
CompareManifests(usize, usize)
Compare two manifests for equality.